@@ -5,23 +5,28 @@ import os
 from contextlib import suppress
 from importlib.util import find_spec
 from pathlib import Path
-from typing import TYPE_CHECKING, Tuple
+from typing import TYPE_CHECKING
 
-from flake8_type_checking.constants import TC001, TC002, TC003, TC004, TC100, TC101, TC200, TC201
-
-if TYPE_CHECKING:
-    from typing import Any, List, Optional
-
-    from flake8_type_checking.types import Flake8Generator, ImportType
+from flake8_type_checking.codes import TC001, TC002, TC003, TC004, TC100, TC101, TC200, TC201
 
 possible_local_errors = ()
 with suppress(ModuleNotFoundError):
-    # noinspection PyUnresolvedReferences
     from django.core.exceptions import AppRegistryNotReady, ImproperlyConfigured
 
+    # TODO: Find a better solution for this
+    # The problem is essentially that we're triggering these errors in Django projects
+    # when running the code in _import_is_local. Perhaps user's could pass a map of which errors
+    # to handle and which values to return
     possible_local_errors += (AppRegistryNotReady, ImproperlyConfigured)  # type: ignore
 
 
+if TYPE_CHECKING:
+    from typing import Any, Generator, Optional, Union
+
+    ImportType = Union[ast.Import, ast.ImportFrom]
+    Flake8Generator = Generator[tuple[int, int, str, Any], None, None]
+
+
 class ImportVisitor(ast.NodeTransformer):
     """Map all imports outside of type-checking blocks."""
 
@@ -67,7 +72,7 @@ class ImportVisitor(ast.NodeTransformer):
         self.futures_annotation: Optional[bool] = None
 
         # Where the type checking block exists (line_start, line_end, col_offset)
-        self.type_checking_blocks: List[tuple[int, int, int]] = []
+        self.type_checking_blocks: list[tuple[int, int, int]] = []
 
         # Function scopes can tell us if imports that appear in type-checking blocks
         # are repeated inside a function. This prevents false TC004 positives.
@@ -207,6 +212,8 @@ class ImportVisitor(ast.NodeTransformer):
 
     def visit_Name(self, node: ast.Name) -> ast.Name:
         """Map names."""
+        if self._in_type_checking_block(node):
+            return node
         if hasattr(node, 'parent'):
             self.uses[f'{node.id}.{node.parent}'] = node  # type: ignore
         self.uses[node.id] = node
@@ -214,6 +221,8 @@ class ImportVisitor(ast.NodeTransformer):
 
     def visit_Constant(self, node: ast.Constant) -> ast.Constant:
         """Map constants."""
+        if self._in_type_checking_block(node):
+            return node
         self.uses[node.value] = node
         return node
 
@@ -245,19 +254,21 @@ class ImportVisitor(ast.NodeTransformer):
         elif isinstance(node, ast.BinOp):
             return
 
-    def visit_Attribute(self, node: ast.Attribute) -> Any:
-        # Set the attribute of the current node
-        try:
-            parent = node.parent  # type: ignore
-            node.attr = f'{node.attr}.{parent}'
-        except Exception:
-            pass
-
+    def _set_child_node_attribute(self, node, attr: str, val: Any):
         # Set the parent attribute on the current node children
         for key, value in node.__dict__.items():
-            if type(value) not in [int, str]:
-                setattr(node.__dict__[key], 'parent', node.attr)
+            if type(value) not in [int, str, list, bool]:
+                setattr(node.__dict__[key], attr, val)
+        return node
 
+    def visit_Attribute(self, node: ast.Attribute) -> Any:
+        # Set the attribute of the current node
+        # This lets us read attribute names for `a.b.c` as `a.b.c` when we're treating the
+        # `c` node, which is important to match attributes to imports
+        with suppress(Exception):
+            parent = node.parent  # type: ignore
+            node.attr = f'{node.attr}.{parent}'
+        node = self._set_child_node_attribute(node, 'parent', node.attr)
         self.generic_visit(node)
         return node
 
